@@ -33,9 +33,8 @@
 # clojure keyword :a => python unicode "a"
 # clojure integer 123 => python integer 123
 # clojure float 12.3 => python float 12.3
-# clojure BigDecimal 12.34M => python decimal.Decimal
 # clojure boolean true => python boolean true
-# clojure nil => python None
+# clojure nil => python None 
 #
 # clojure datetime => python datetime
 # clojure uuid => python uuid
@@ -47,16 +46,13 @@ __all__ = ["dump", "dumps", "load", "loads"]
 import os
 from cStringIO import StringIO
 
-import decimal
 import uuid
 from datetime import datetime
 import pyrfc3339
 import pytz
 
 def number(v):
-    if v.endswith('M'):
-        return decimal.Decimal(v[:-1])
-    elif '.' in v:
+    if '.' in v:
         return float(v)
     else:
         return int(v)
@@ -64,7 +60,7 @@ def number(v):
 _STOP_CHARS = [" ", ",", "\n", "\r", "\t"]
 _COLL_OPEN_CHARS = ["#", "[", "{", "("]
 _COLL_CLOSE_CHARS = ["]", "}", ")"]
-_EXTRA_NUM_CHARS = ["-", "+", ".", "e", "E", "M"]
+_EXTRA_NUM_CHARS = ["-", "+", ".", "e", "E"]
 
 class CljDecoder(object):
     def __init__(self, fd):
@@ -87,7 +83,7 @@ class CljDecoder(object):
         s = self.fd.read(size)
         self.__seek_back(size)
         return s
-
+        
     def __get_type_from_char(self, c):
         """return a tuple of type information
         * type name
@@ -118,7 +114,7 @@ class CljDecoder(object):
             return ("list", True, ")")
         elif c == '[':
             return ('list', True, "]")
-
+        
         return (None, False, None)
 
     def __read_fd(self, size):
@@ -136,7 +132,7 @@ class CljDecoder(object):
     def __read_token(self):
         c = self.__read_fd(1)
 
-        ## skip all stop chars if necessary
+        ## skip all stop chars if necessary 
         while c in _STOP_CHARS:
             c = self.__read_fd(1)
 
@@ -146,13 +142,13 @@ class CljDecoder(object):
 
         t, coll, term = self.__get_type_from_char(c)
         if coll:
-            ## move cursor
+            ## move cursor 
             if t == "set":
                 ## skip {
                 self.__read_fd(1)
 
             self.terminator = term
-
+                
             self.value_stack.append(([], self.terminator, t))
             return None
         else:
@@ -179,7 +175,7 @@ class CljDecoder(object):
                 while c is not self.terminator and c is not "" and c not in _STOP_CHARS:
                     c = self.__read_fd(1)
                     buf.append(c)
-
+                
                 e = c
                 v = ''.join(buf[:-1])
 
@@ -199,7 +195,7 @@ class CljDecoder(object):
                 numstr = ''.join(buf)
                 v = number(numstr)
 
-                ## special case for
+                ## special case for 
                 ## [23[12]]
                 ## this is a valid clojure form
                 if e in _COLL_OPEN_CHARS:
@@ -210,7 +206,7 @@ class CljDecoder(object):
                 while c is not self.terminator and c is not "" and c not in _STOP_CHARS:
                     c = self.__read_fd(1)
                     buf.append(c)
-
+ 
                 e = c
                 v = ''.join(buf[:-1])
 
@@ -225,7 +221,7 @@ class CljDecoder(object):
                 e = c
                 #v = u''.join(buf).decode('unicode-escape')
                 v = ''.join(buf).decode('string-escape')
-
+                
             elif t == "datetime":
                 ## skip "inst"
                 self.__read_fd(4)
@@ -244,7 +240,7 @@ class CljDecoder(object):
             elif t == "uuid":
                 ## skip "uuid"
                 self.__read_fd(4)
-
+                
                 ## read next value as string
                 s = self.__read_token()
                 if not isinstance(s, str):
@@ -267,12 +263,9 @@ class CljDecoder(object):
 
                 if r:
                     current_scope.append(v)
-
+                    
                 if container == "set":
-                    try:
-                        v = set(current_scope)
-                    except TypeError:
-                        v = tuple(current_scope)
+                    v = set(current_scope)
                 elif container == "list":
                     v = current_scope
                 elif container == "dict":
@@ -306,8 +299,6 @@ class CljEncoder(object):
             return ("boolean", False)
         elif isinstance(t, (int,float,long)):
             return ("number", False)
-        elif isinstance(t, decimal.Decimal):
-            return ("decimal", False)
         elif isinstance(t, dict):
             return ("dict", True)
         elif isinstance(t, (list,tuple)):
@@ -331,7 +322,7 @@ class CljEncoder(object):
                 raise ValueError('Circular reference detected')
             else:
                 self.circular[refid] = True
-
+            
             if t == "dict":
                 fd.write("{")
                 if len(d) > 0:
@@ -361,8 +352,6 @@ class CljEncoder(object):
         else:
             if t == "number":
                 fd.write(str(d))
-            elif t == "decimal":
-                fd.write(str(d) + 'M')
             elif t == "string":
                 s = d.encode("string-escape").replace('"', '\\"')
                 fd.write('"'+s+'"')
@@ -384,7 +373,7 @@ class CljEncoder(object):
                 fd.write("#uuid \"%s\"" % s)
             else:
                 fd.write('"'+str(d)+'"')
-
+    
 def dump(obj, fp):
     return CljEncoder(obj, fp).encode()
 
@@ -404,3 +393,4 @@ def loads(s):
     result = load(buf)
     buf.close()
     return result
+
